# Deploy tasks and helpers for application

[![Build Status](https://readthedocs.org/projects/unv_deploy/badge/?version=latest&style=flat)](https://readthedocs.org/projects/unv_deploy)
[![Docs Build Status](https://travis-ci.org/c137digital/unv_deploy.svg?branch=master)](https://travis-ci.org/c137digital/unv_deploy)
[![Maintainability](https://api.codeclimate.com/v1/badges/d55631dca90a900ce134/maintainability)](https://codeclimate.com/github/c137digital/unv_deploy/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/d55631dca90a900ce134/test_coverage)](https://codeclimate.com/github/c137digital/unv_deploy/test_coverage)
[![Requirements Status](https://requires.io/github/c137digital/unv_deploy/requirements.svg?branch=master)](https://requires.io/github/c137digital/unv_deploy/requirements/?branch=master)
[![PyPI implementation](https://img.shields.io/pypi/implementation/unv_deploy.svg)](https://pypi.python.org/pypi/unv_deploy/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/unv_deploy.svg)](https://pypi.python.org/pypi/unv_deploy/)
[![PyPI license](https://img.shields.io/pypi/l/unv_deploy.svg)](https://pypi.python.org/pypi/unv_deploy/)
[![PyPI version fury.io](https://badge.fury.io/py/unv_deploy.svg)](https://pypi.python.org/pypi/unv_deploy/)
[![PyPI download month](https://img.shields.io/pypi/dm/unv_deploy.svg)](https://pypi.python.org/pypi/unv_deploy/)
